@@ -39,6 +39,7 @@ class Spec214Schema(Schema):
         daaxes: int,
         npropos: int = 1,
         nexpers: int = 1,
+        nspeclns: int = 0,
         instrument=None,
         random=None,
     ):
@@ -50,6 +51,7 @@ class Spec214Schema(Schema):
             DAAXES=daaxes,
             NPROPOS=npropos,
             NEXPERS=nexpers,
+            NSPECLNS=nspeclns,
         )
         sections.pop("compression", None)
         if instrument:
@@ -91,7 +93,7 @@ class Spec214Dataset(Dataset):
         swnroi: int = 0,
         hwnroi: int = 0,
     ):
-
+        nspeclns = 3
         # We have to recalculate a bunch of stuff from the super init here to
         # expand the schema before we call the super constructor.
         data_shape = tuple(d for d in array_shape if d != 1)
@@ -103,6 +105,7 @@ class Spec214Dataset(Dataset):
                 daaxes=len(data_shape),
                 npropos=1,
                 nexpers=1,
+                nspeclns=nspeclns,
                 instrument=instrument,
             ),
             dataset_shape=dataset_shape,
@@ -191,6 +194,11 @@ class Spec214Dataset(Dataset):
         self.add_constant_key("IDSCALID", 3)
         self.add_constant_key("OBSPR_ID", "OPID")
         self.add_constant_key("IP_ID", "IPID")
+        # This has to be passed through to the schema to expand the index
+        self.add_constant_key("NSPECLNS", nspeclns)
+        self.add_constant_key("SPECLN01", "Ca II")
+        self.add_constant_key("SPECLN02", "H alpha")
+        self.add_constant_key("SPECLN03", "Fe I")
         self.add_constant_key("HEADVERS", "HEADERVERSION")
         self.add_constant_key("HEAD_URL", "HEADERURL")
         self.add_constant_key("INFO_URL", "INFOURL")
@@ -492,7 +500,8 @@ class AOMixin:
     AOLOOPI: Same as above but use 10 for a typical value.
     FRMRATE: This should always be 1970 Hz except in rare cases for engineering purposes
     FRMLOCK: This is similar to WFC__002 above but for the tip-tilt system. Use values as described above. They don't have to be the same as the WFC_002 values.
-    TTLOOPP, TTLOOPI: Similar to 004 and 005 above but use 0.2 and 1 for typical values, respectively."""
+    TTLOOPP, TTLOOPI: Similar to 004 and 005 above but use 0.2 and 1 for typical values, respectively.
+    """
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
