@@ -19,7 +19,6 @@ class BaseDLNIRSPDataset(Spec214Dataset):
         linewave,
         array_shape=(100, 100, 100)
     ):
-
         if not n_exposures:
             raise NotImplementedError(
                 "Support for less than 4D DLNIRSP datasets is not implemented."
@@ -28,7 +27,7 @@ class BaseDLNIRSPDataset(Spec214Dataset):
         array_shape = list(array_shape)
 
         dataset_shape_rev = list(array_shape) + [n_exposures]
-        if n_stokes:
+        if n_stokes > 1:
             dataset_shape_rev += [n_stokes]
 
         super().__init__(
@@ -58,11 +57,12 @@ class BaseDLNIRSPDataset(Spec214Dataset):
         self.add_constant_key("DWNAME4", "time")
         self.add_constant_key("DUNIT4", "s")
 
-        if n_stokes:
+        if n_stokes > 1:
             self.add_constant_key("DTYPE5", "STOKES")
             self.add_constant_key("DPNAME5", "stokes")
             self.add_constant_key("DWNAME5", "stokes")
             self.add_constant_key("DUNIT5", "")
+            self.stokes_file_axis = 0
 
         self.add_constant_key("LINEWAV", linewave.to_value(u.nm))
 
@@ -72,6 +72,7 @@ class BaseDLNIRSPDataset(Spec214Dataset):
             10 * u.arcsec / u.pix,
             1 * u.nm / u.pix,
         )
+        self.n_stokes = n_stokes
 
 
 class SimpleDLNIRSPDataset(BaseDLNIRSPDataset):
@@ -81,6 +82,13 @@ class SimpleDLNIRSPDataset(BaseDLNIRSPDataset):
 
     name = "dlnirsp-simple"
 
+    @property
+    def non_temporal_file_axes(self):
+        if self.n_stokes > 1:
+            # This is the index in file shape so third file dimension
+            return (0,)
+        return super().non_temporal_file_axes
+
     @property
     def data(self):
         return np.random.random(self.array_shape)
@@ -101,6 +109,6 @@ class SimpleDLNIRSPDataset(BaseDLNIRSPDataset):
         w.wcs.crval = 0, 0, 0
         w.wcs.cdelt = [self.plate_scale[i].value for i in range(self.array_ndim)]
         w.wcs.cunit = "arcsec", "arcsec", "nm"
-        w.wcs.ctype = "HPLN-TAN", "HPLT-TAN", "WAVE"
+        w.wcs.ctype = "HPLN-TAN", "HPLT-TAN", "AWAV"
         w.wcs.pc = np.identity(self.array_ndim)
         return w
