@@ -24,7 +24,6 @@ class BaseVBIDataset(Spec214Dataset):
         vbi_camera: Literal["red", "blue"] = "red",
         mosaic: bool = False
     ):
-
         if vbi_camera.lower() not in ["red", "blue"]:
             raise ValueError("vbi_camera must either be 'red' or 'blue'")
 
@@ -52,7 +51,7 @@ class BaseVBIDataset(Spec214Dataset):
         )
         self.files_shape = (*self.files_shape, n_pos)
         self.files_ndim = len(self.files_shape)
-        self.n_files = int(np.product(self.files_shape))
+        self.n_files = int(np.prod(self.files_shape))
 
         self.add_constant_key("DTYPE1", "SPATIAL")
         self.add_constant_key("DTYPE2", "SPATIAL")
