@@ -9,14 +9,13 @@
 
 # -- Project information -----------------------------------------------------
 
-project = "dkist-data-simulator"
-copyright = "2020, AURA / NSO"
-author = "AURA / NSO"
-
 # The full version, including alpha/beta/rc tags
 from dkist_data_simulator import __version__
 
 release = __version__
+project = "dkist-data-simulator"
+copyright = "2020, AURA / NSO"
+author = "AURA / NSO"
 
 # -- General configuration ---------------------------------------------------
 
@@ -66,8 +65,7 @@ napoleon_use_param = True
 # -- Options for intersphinx extension ---------------------------------------
 
 # Example configuration for intersphinx: refer to the Python standard library.
-intersphinx_mapping = {"https://docs.python.org/": None}
-
+intersphinx_mapping = {"python": ("https://docs.python.org/3", None)}
 # -- Options for HTML output -------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
